@@ -5,7 +5,6 @@ mod udiff_spec {
   use regex::Regex;
   use std::{
     collections::HashSet,
-    ffi::OsStr,
     fs::{read_dir, read_to_string},
     path::PathBuf,
   };
@@ -101,7 +100,7 @@ mod udiff_spec {
           }
         })
         .collect::<Vec<_>>();
-      let imp = udiff(None, unified, &OsStr::new(""), &before, &after)
+      let imp = udiff(None, unified, Default::default(), &before, &after)
         .to_string_lossy()
         .split_inclusive("\n")
         .skip(3)
